@@ -1,18 +1,17 @@
-## Copyright (C) 2008  Francesco Potort  <pot@gnu.org>
+## Copyright (C) 2008 Francesco Potort <pot@gnu.org>
 ##
-## This software is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3, or (at your option)
-## any later version.
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
 ##
-## This software is distributed in the hope that it will be useful, but
-## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
 ##
-## You should have received a copy of the GNU General Public License
-## along with this software; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {@var{y} =} linkage (@var{d})
@@ -24,7 +23,7 @@
 ##
 ## Produce a hierarchical clustering dendrogram
 ##
-## @var{d} is the dissimilarity matrix relative to @var{n} observations,
+## @var{d} is the dissimilarity matrix relative to n observations,
 ## formatted as a @math{(n-1)*n/2}x1 vector as produced by @code{pdist}.
 ## Alternatively, @var{x} contains data formatted for input to
 ## @code{pdist}, @var{metric} is a metric for @code{pdist} and
@@ -32,11 +31,11 @@
 ## @code{pdist}.
 ##
 ## @code{linkage} starts by putting each observation into a singleton
-## cluster and numbering those from 1 to @var{n}.  Then it merges two
+## cluster and numbering those from 1 to n.  Then it merges two
 ## clusters, chosen according to @var{method}, to create a new cluster
-## numbered @var{n+1}, and so on until all observations are grouped into
-## a single cluster numbered @var{2*n-1}.  Row @var{m} of the
-## @math{m-1}x3 output matrix relates to cluster @math{n+m}: the first
+## numbered n+1, and so on until all observations are grouped into
+## a single cluster numbered 2(n-1).  Row k of the
+## (m-1)x3 output matrix relates to cluster n+k: the first
 ## two columns are the numbers of the two component clusters and column
 ## 3 contains their distance.
 ##
@@ -105,14 +104,14 @@ function dgram = linkage (d, method = "single", distarg)
 
   methods = struct ...
   ("name", { "single"; "complete"; "average"; "weighted";
-	    "centroid"; "median"; "ward" },
-   "distfunc", {(@(x) min(x))				     # single
-		(@(x) max(x))				     # complete
-		(@(x,i,j,w) sum(dmult(q=w([i,j]),x))/sum(q)) # average
-		(@(x) mean(x))				     # weighted
-		(@massdist)				     # centroid
-		(@(x,i) massdist(x,i))			     # median
-		(@inertialdist)				     # ward
+            "centroid"; "median"; "ward" },
+   "distfunc", {(@(x) min(x))                                # single
+                (@(x) max(x))                                # complete
+                (@(x,i,j,w) sum(diag(q=w([i,j]))*x)/sum(q))  # average
+                (@(x) mean(x))                               # weighted
+                (@massdist)                                  # centroid
+                (@(x,i) massdist(x,i))                       # median
+                (@inertialdist)                              # ward
    });
   mask = strcmp (lower (method), {methods.name});
   if (! any (mask))
@@ -131,16 +130,16 @@ function dgram = linkage (d, method = "single", distarg)
   endif
 
   d = squareform (d, "tomatrix");      # dissimilarity NxN matrix
-  n = rows (d);			       # the number of observations
+  n = rows (d);                        # the number of observations
   diagidx = sub2ind ([n,n], 1:n, 1:n); # indices of diagonal elements
-  d(diagidx) = Inf;	# consider a cluster as far from itself
+  d(diagidx) = Inf;     # consider a cluster as far from itself
   ## For equal-distance nodes, the order in which clusters are
   ## merged is arbitrary.  Rotating the initial matrix produces an
   ## ordering similar to Matlab's.
-  cname = n:-1:1;		# cluster names in d
-  d = rot90 (d, 2);		# exchange low and high cluster numbers
-  weight = ones (1, n);		# cluster weights
-  dgram = zeros (n-1, 3);	# clusters from n+1 to 2*n-1
+  cname = n:-1:1;               # cluster names in d
+  d = rot90 (d, 2);             # exchange low and high cluster numbers
+  weight = ones (1, n);         # cluster weights
+  dgram = zeros (n-1, 3);       # clusters from n+1 to 2*n-1
   for cluster = n+1:2*n-1
     ## Find the two nearest clusters
     [m midx] = min (d(:));
@@ -152,7 +151,7 @@ function dgram = linkage (d, method = "single", distarg)
     cname(c) = [];
     ## Compute the new distances
     newd = dist (d([r c], :), r, c, weight);
-    newd(r) = Inf;		# take care of the diagonal element
+    newd(r) = Inf;              # take care of the diagonal element
     ## Put distances in place of the first ones, remove the second ones
     d(r,:) = newd;
     d(:,r) = newd';
@@ -168,8 +167,8 @@ function dgram = linkage (d, method = "single", distarg)
   ## Check that distances are monotonically increasing
   if (any (diff (dgram(:,3)) < 0))
     warning ("clustering",
-	     "linkage: cluster distances do not monotonically increase\n\
-	you should probably use a method different from \"%s\"", method);
+             "linkage: cluster distances do not monotonically increase\n\
+        you should probably use a method different from \"%s\"", method);
   endif
 
 endfunction
@@ -181,11 +180,11 @@ endfunction
 ## clusters. Use the law of cosines to find the distances of the new
 ## cluster from all the others.
 function y = massdist (x, i, j, w)
-  x .^= 2;			# squared Euclidean distances
-  if (nargin == 2)		# median distance
-    qi = 0.5;			# equal weights ("weighted")
-  else				# centroid distance
-    qi = 1 / (1 + w(j) / w(i));	# proportional weights ("unweighted")
+  x .^= 2;                      # squared Euclidean distances
+  if (nargin == 2)              # median distance
+    qi = 0.5;                   # equal weights ("weighted")
+  else                          # centroid distance
+    qi = 1 / (1 + w(j) / w(i)); # proportional weights ("unweighted")
   endif
   y = sqrt (qi*x(1,:) + (1-qi)*(x(2,:) - qi*x(2,i)));
 endfunction
@@ -199,18 +198,17 @@ endfunction
 ## other clusters, convert them back to inertial distances and return
 ## them.
 function y = inertialdist (x, i, j, w)
-  wi = w(i); wj = w(j);	# the cluster weights
-  s = [wi + w; wj + w];	# sum of weights for all cluster pairs
-  p = [wi * w; wj * w];	# product of weights for all cluster pairs
-  x = x.^2 .* s ./ p;	# convert inertial dist. to squared Eucl.
-  sij = wi + wj;	# sum of weights of I and J
-  qi = wi/sij;		# normalise the weight of I
+  wi = w(i); wj = w(j); # the cluster weights
+  s = [wi + w; wj + w]; # sum of weights for all cluster pairs
+  p = [wi * w; wj * w]; # product of weights for all cluster pairs
+  x = x.^2 .* s ./ p;   # convert inertial dist. to squared Eucl.
+  sij = wi + wj;        # sum of weights of I and J
+  qi = wi/sij;          # normalise the weight of I
   ## Squared Euclidean distances between all clusters and new cluster K
   x = qi*x(1,:) + (1-qi)*(x(2,:) - qi*x(2,i));
   y = sqrt (x * sij .* w ./ (sij + w)); # convert Eucl. dist. to inertial
 endfunction
 
-
 %!shared x, t
 %! x = reshape(mod(magic(6),5),[],3);
 %! t = 1e-6;
@@ -218,6 +216,7 @@ endfunction
 %!assert (cond (linkage (pdist (x), "complete")),  21.793345,t);
 %!assert (cond (linkage (pdist (x), "average")),   27.045012,t);
 %!assert (cond (linkage (pdist (x), "weighted")),  27.412889,t);
+%! lastwarn(); # Clear last warning before the test
 %!warning <monotonically> linkage (pdist (x), "centroid");
 %!test warning off clustering
 %! assert (cond (linkage (pdist (x), "centroid")), 27.457477,t);
